==> 0.0.2.tar.gz: ios/Classes/AdManager/YFAdsBannerManager.m <==
#import "YFAdsBannerManager.h"
#import <Foundation/Foundation.h>
#import "YFAdsConstant.h"
#import <Flutter/Flutter.h>
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdBanner.h>

@interface YFAdsBannerManager ()<YFAdBannerDelegate>

@property (nonatomic, strong) FlutterEventSink flutterEventSink;
@property (nonatomic, strong) UIViewController * viewController;
@property (nonatomic, strong) YFAdBanner * bannerAd;
@property (nonatomic, strong) UIView *bannerView;
@property (nonatomic, strong) NSNumber *currentUniqueKey;
@end

@implementation YFAdsBannerManager

NSValue *expressFeedAd = false;
NSString *adType;

- (instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(UIViewController *)viewController {
    self = [super init];
    _flutterEventSink = flutterEventSink;
    _viewController = viewController;
    adType = AD_TYPE_BANNER;
    return self;
}

- (void)showAd:(NSDictionary *)parametersDic {
    NSString *positionId = parametersDic[KEY_POSITION_ID];
     _currentUniqueKey = parametersDic[KEY_UNIQUE_KEY];
    NSLog(@"showAd currentUniqueKey is %@",_currentUniqueKey);
    NSNumber *width = parametersDic[KEY_BANNER_VIEW_WIDTH];
    NSNumber *height = parametersDic[KEY_BANNER_VIEW_HEIGHT];
  
    float configWidth = 0;
    if([width  isKindOfClass:NSNumber.class] && width.floatValue > 0){
        configWidth = width.floatValue;
    }
    float configHeight = 0;
    if([height  isKindOfClass:NSNumber.class] && height.floatValue > 0){
        configHeight = height.floatValue;
    }
    NSLog(@"showAd configWidth configHeight is %f %f",configWidth,configHeight);
    CGSize size = CGSizeMake(configWidth, configHeight);
    expressFeedAd = parametersDic[KEY_BANNER_EXPRESS_FEED_AD];
//    if(expressFeedAd && expressFeedAd != [NSNull null]){
//        adType = AD_TYPE_EXPRESS_FEED;
//    }

//    NSNumber *adSizeIndex = parametersDic[KEY_BANNER_SIZE_INDEX];
//    int index = adSizeIndex.intValue;
//    int destSizeType = index;
//    index = (index >= self.supportSizeTypes.count || index < 0) ? 0 : index;
//    WHBannerSizeType type = ((NSNumber *)self.supportSizeTypes[index]).intValue;
//    destSizeType = type;
//    bool showDislike = parametersDic[KEY_BANNER_VIEW_SHOW_DISLIKE];
//
//
    
    
        if (!_bannerView) {
            _bannerView = [[UIView alloc] initWithFrame:CGRectMake(0,0, configWidth, configHeight)];
        }
    
        _bannerAd = [[YFAdBanner alloc] initWithAdUnitID:positionId adContainer:_bannerView viewController:self.viewController];
        _bannerAd.delegate = self;
        [_bannerAd loadAndShowAd];
  
}

- (void)callRendSuccess {
    if([self.flutterBannerDelegate respondsToSelector:@selector(yfBannerViewRenderSuccess:)]){
        [self.flutterBannerDelegate yfBannerViewRenderSuccess:self.bannerView];
    }
    [self callContainerSizeChanged];
}

- (void)callContainerSizeChanged {
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"onContainerSizeChanged" forKey:KEY_METHOD];
    [result setValue:@(self.bannerView.bounds.size.height) forKey:KEY_EXPRESS_FEED_VIEW_HEIGHT];
    [self callBack:result];
    NSLog(@"callContainerSizeChanged %@", result);
}


-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:adType forKey:KEY_AD_TYPE];
    [resultDic setValue:_currentUniqueKey forKey:KEY_VIEW_ID];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}

- (void)deallocAd {
    [self.bannerView removeFromSuperview];
    self.bannerView = nil;
    if (self.bannerAd) {
        self.bannerAd.delegate = nil;
        self.bannerAd = nil;
    }
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告请求成功 %s  ", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdDidLoad" forKey:KEY_METHOD];
    [self callBack:result];
    if([self.flutterBannerDelegate respondsToSelector:@selector(yfBannerViewLoadSuccess:)]){
        [self.flutterBannerDelegate yfBannerViewLoadSuccess:self.bannerView];
    }
    if (self.bannerView.frame.size.height > 0) {
        [self callRendSuccess];
    }
}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description{
    NSLog(@"广告展示失败 %s  error: %@ 详情:%@", __func__, error, description);
    NSString *errorMessage = [NSString stringWithFormat:@"%@%@",@"banner ad load failed:",error.localizedDescription];
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdLoadFail" forKey:KEY_METHOD];
    [result setValue:errorMessage forKey:KEY_ERROR];
    [self callBack:result];
    [self deallocAd];
}

/// 广告曝光
- (void)fcAdExposured:(id)adapter {
    NSLog(@"广告曝光回调 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdExposed" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked:(id)adapter  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdClicked" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告关闭回调
- (void)fcAdDidClose:(id)adapter  {
    NSLog(@"广告关闭了 %s", __func__);
    if([self.flutterBannerDelegate respondsToSelector:@selector(yfBannerViewDislike)]){
        [self.flutterBannerDelegate yfBannerViewDislike];
    }
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdClosed" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

-(void)dealloc {
    NSLog(@"横幅释放 %s", __func__);
    [self deallocAd];
}

@end

==> 0.0.10.tar.gz: ios/Classes/AdManager/YFAdsBannerManager.m <==
#import "YFAdsBannerManager.h"
#import <Foundation/Foundation.h>
#import "YFAdsConstant.h"
#import <Flutter/Flutter.h>
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdBanner.h>

@interface YFAdsBannerManager ()<YFAdBannerDelegate>

@property (nonatomic, strong) FlutterEventSink flutterEventSink;
@property (nonatomic, strong) UIViewController * viewController;
@property (nonatomic, strong) YFAdBanner * bannerAd;
@property (nonatomic, strong) UIView *bannerView;
@property (nonatomic, strong) NSNumber *currentUniqueKey;
@property (nonatomic, strong) FlutterResult flutterResult;
@property (nonatomic, assign) BOOL isLoadAndShow;

@end

@implementation YFAdsBannerManager

NSValue *expressFeedAd = false;
NSString *adType;


-(instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(UIViewController *)viewController result:(FlutterResult)flutterResult {
    self = [super init];
    _flutterEventSink = flutterEventSink;
    _viewController = viewController;
    _flutterResult = flutterResult;

    return self;
}

- (instancetype)initWithParams:(FlutterEventSink)flutterEventSink viewController:(UIViewController *)viewController {
    self = [super init];
    _flutterEventSink = flutterEventSink;
    _viewController = viewController;
    adType = AD_TYPE_BANNER;
    return self;
}

-(void)showAd {
    if(_bannerAd && self.bannerView){
        if([self.flutterBannerDelegate respondsToSelector:@selector(yfBannerViewLoadSuccess:)]){
            [self.flutterBannerDelegate yfBannerViewLoadSuccess:self.bannerView];
        }
        if (self.bannerView.frame.size.height > 0) {
            [self callRendSuccess];
        }
    }
}


-(void)loadAd:(NSDictionary *)parametersDic {
    
    self.isLoadAndShow = NO;
    
    NSString *positionId = parametersDic[KEY_POSITION_ID];
     _currentUniqueKey = parametersDic[KEY_UNIQUE_KEY];
    NSLog(@"showAd currentUniqueKey is %@",_currentUniqueKey);
    NSNumber *width = parametersDic[KEY_BANNER_VIEW_WIDTH];
    NSNumber *height = parametersDic[KEY_BANNER_VIEW_HEIGHT];
  
    float configWidth = 0;
    if([width  isKindOfClass:NSNumber.class] && width.floatValue > 0){
        configWidth = width.floatValue;
    }
    float configHeight = 0;
    if([height  isKindOfClass:NSNumber.class] && height.floatValue > 0){
        configHeight = height.floatValue;
    }
    NSLog(@"showAd configWidth configHeight is %f %f",configWidth,configHeight);
    CGSize size = CGSizeMake(configWidth, configHeight);
    expressFeedAd = parametersDic[KEY_BANNER_EXPRESS_FEED_AD];
//    if(expressFeedAd && expressFeedAd != [NSNull null]){
//        adType = AD_TYPE_EXPRESS_FEED;
//    }

//    NSNumber *adSizeIndex = parametersDic[KEY_BANNER_SIZE_INDEX];
//    int index = adSizeIndex.intValue;
//    int destSizeType = index;
//    index = (index >= self.supportSizeTypes.count || index < 0) ? 0 : index;
//    WHBannerSizeType type = ((NSNumber *)self.supportSizeTypes[index]).intValue;
//    destSizeType = type;
//    bool showDislike = parametersDic[KEY_BANNER_VIEW_SHOW_DISLIKE];
//
//
    
        if (!_bannerView) {
            _bannerView = [[UIView alloc] initWithFrame:CGRectMake(0,0, configWidth, configHeight)];
        }
    
        _bannerAd = [[YFAdBanner alloc] initWithAdUnitID:positionId adContainer:_bannerView viewController:self.viewController];
        _bannerAd.delegate = self;
        [_bannerAd loadAndShowAd];
}
-(void)loadAndShow:(NSDictionary *)parametersDic {
    
    self.isLoadAndShow = YES;

    NSString *positionId = parametersDic[KEY_POSITION_ID];
     _currentUniqueKey = parametersDic[KEY_UNIQUE_KEY];
    NSLog(@"showAd currentUniqueKey is %@",_currentUniqueKey);
    NSNumber *width = parametersDic[KEY_BANNER_VIEW_WIDTH];
    NSNumber *height = parametersDic[KEY_BANNER_VIEW_HEIGHT];
  
    float configWidth = 0;
    if([width  isKindOfClass:NSNumber.class] && width.floatValue > 0){
        configWidth = width.floatValue;
    }
    float configHeight = 0;
    if([height  isKindOfClass:NSNumber.class] && height.floatValue > 0){
        configHeight = height.floatValue;
    }
    NSLog(@"showAd configWidth configHeight is %f %f",configWidth,configHeight);
    CGSize size = CGSizeMake(configWidth, configHeight);
    expressFeedAd = parametersDic[KEY_BANNER_EXPRESS_FEED_AD];
//    if(expressFeedAd && expressFeedAd != [NSNull null]){
//        adType = AD_TYPE_EXPRESS_FEED;
//    }

//    NSNumber *adSizeIndex = parametersDic[KEY_BANNER_SIZE_INDEX];
//    int index = adSizeIndex.intValue;
//    int destSizeType = index;
//    index = (index >= self.supportSizeTypes.count || index < 0) ? 0 : index;
//    WHBannerSizeType type = ((NSNumber *)self.supportSizeTypes[index]).intValue;
//    destSizeType = type;
//    bool showDislike = parametersDic[KEY_BANNER_VIEW_SHOW_DISLIKE];
//
//
    
    
        if (!_bannerView) {
            _bannerView = [[UIView alloc] initWithFrame:CGRectMake(0,0, configWidth, configHeight)];
        }
    
        _bannerAd = [[YFAdBanner alloc] initWithAdUnitID:positionId adContainer:_bannerView viewController:self.viewController];
        _bannerAd.delegate = self;
        [_bannerAd loadAndShowAd];
}


- (void)callRendSuccess {
    if([self.flutterBannerDelegate respondsToSelector:@selector(yfBannerViewRenderSuccess:)]){
        [self.flutterBannerDelegate yfBannerViewRenderSuccess:self.bannerView];
    }
    [self callContainerSizeChanged];
}

- (void)callContainerSizeChanged {
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"onContainerSizeChanged" forKey:KEY_METHOD];
    [result setValue:@(self.bannerView.bounds.size.height) forKey:KEY_EXPRESS_FEED_VIEW_HEIGHT];
    [self callBack:result];
    NSLog(@"callContainerSizeChanged %@", result);
}


-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:adType forKey:KEY_AD_TYPE];
    [resultDic setValue:_currentUniqueKey forKey:KEY_VIEW_ID];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}

- (void)deallocAd {
    [self.bannerView removeFromSuperview];
    self.bannerView = nil;
    if (self.bannerAd) {
        self.bannerAd.delegate = nil;
        self.bannerAd = nil;
    }
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告请求成功 %s  ", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdDidLoad" forKey:KEY_METHOD];
    NSString *ecpm = [NSString stringWithFormat:@"%zd",model.ecpm];
    [result setValue:ecpm forKey:KEY_ECPM];
    [self callBack:result];
    [self showAd];    
}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description{
    NSLog(@"广告展示失败 %s  error: %@ 详情:%@", __func__, error, description);
    NSString *errorMessage = [NSString stringWithFormat:@"%@%@",@"banner ad load failed:",error.localizedDescription];
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdLoadFail" forKey:KEY_METHOD];
    [result setValue:errorMessage forKey:KEY_ERROR];
    [self callBack:result];
    [self deallocAd];
}

/// 广告曝光
- (void)fcAdExposured:(id)adapter {
    NSLog(@"广告曝光回调 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdExposed" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked:(id)adapter  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdClicked" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告关闭回调
- (void)fcAdDidClose:(id)adapter  {
    NSLog(@"广告关闭了 %s", __func__);
    if([self.flutterBannerDelegate respondsToSelector:@selector(yfBannerViewDislike)]){
        [self.flutterBannerDelegate yfBannerViewDislike];
    }
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfBannerAdClosed" forKey:KEY_METHOD];
    [self callBack:result];
    [self deallocAd];
}

-(void)dealloc {
    NSLog(@"横幅释放 %s", __func__);
    [self deallocAd];
}

@end
